
(function_declaration
 (function_body_declaration
  (function_identifier
     (function_identifier
        (simple_identifier) @function.inner)))) @function.outer

(comment) @comment.inner

(comment)+ @comment.outer
