; Vue SFC blocks and template elements as xml-element textobjects, mirroring
; html. <script>/<style> bodies are a single raw_text child; template elements
; can hold many children.
(script_element (start_tag) (_) @xml-element.inner (end_tag)) @xml-element.outer

(style_element (start_tag) (_) @xml-element.inner (end_tag)) @xml-element.outer

(template_element (start_tag) (_)* @xml-element.inner (end_tag)) @xml-element.outer

(element (start_tag) (_)* @xml-element.inner (end_tag))

(element) @xml-element.outer

(comment) @comment.outer
