; See runtime/queries/ecma/README.md for more info.

(jsx_self_closing_element) @xml-element.outer @xml-element.inner

(jsx_element (jsx_opening_element) (_)* @xml-element.inner (jsx_closing_element))

(jsx_element) @xml-element.outer
