(section 
  (identifier) 
  (_)
  (property) @class.inner
) @class.outer

(attribute 
  (identifier)
  (_) @parameter.inner) @parameter.outer

(property 
  (path)
  (_) @entry.inner) @entry.outer

(pair 
  (_) @entry.inner) @entry.outer

(array
  (_) @entry.outer)

(comment) @comment.inner

(comment)+ @comment.outer
