
(func_def name: (identifier) (block) @function.inner) @function.outer

(param_list (_) @parameter.inner) @parameter.outer

(args (_) @parameter.inner) @parameter.outer

(comment) @comment.inner

(comment)+ @comment.outer
