;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "evil-textobj-tree-sitter" "20260616.730"
  "Provides evil textobjects using tree-sitter."
  '((emacs "25.1"))
  :url "https://github.com/meain/evil-textobj-tree-sitter"
  :commit "fecc0e11615df31a6651ce11b012388e53cad4e9"
  :revdesc "fecc0e11615d"
  :keywords '("evil" "tree-sitter" "text-object" "convenience"))
